summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--board/halvor/board.c25
-rw-r--r--board/halvor/board.h2
2 files changed, 24 insertions, 3 deletions
diff --git a/board/halvor/board.h b/board/halvor/board.h
index bb7aab421a..1b7c198f5d 100644
--- a/board/halvor/board.h
+++ b/board/halvor/board.h
@@ -150,6 +150,8 @@ void halvor_tcpc_alert_event(enum gpio_signal signal);
void halvor_ppc_interrupt(enum gpio_signal signal);
void halvor_bc12_interrupt(enum gpio_signal signal);
+void board_reset_pd_mcu(void);
+
#endif /* !__ASSEMBLER__ */
#endif /* __CROS_EC_BOARD_H */
diff --git a/board/halvor/board.c b/board/halvor/board.c
index 8bf58af26a..5180bf6bbf 100644
--- a/board/halvor/board.c
+++ b/board/halvor/board.c
@@ -8,6 +8,7 @@
#include "button.h"
#include "common.h"
#include "accelgyro.h"
+#include "cbi_ec_fw_config.h"
#include "driver/accel_bma2x2.h"
#include "driver/als_tcs3400.h"
#include "driver/sync.h"
@@ -29,6 +30,14 @@
#include "gpio_list.h" /* Must come after other header files. */
+/*
+ * FW_CONFIG defaults for Halvor if the CBI data is not initialized.
+ */
+union volteer_cbi_fw_config fw_config_defaults = {
+ /* Set all FW_CONFIG fields default to 0 */
+ .raw_value = 0,
+};
+
static void board_init(void)
{
/* Illuminate motherboard and daughter board LEDs equally to start. */
@@ -165,15 +174,25 @@ BUILD_ASSERT(ARRAY_SIZE(pwm_channels) == PWM_CH_COUNT);
/******************************************************************************/
void halvor_tcpc_alert_event(enum gpio_signal signal)
{
- /* TODO (b/153705222): Need tp implement three USB-C function */
+ /* TODO (b/153705222): Need to implement three USB-C function */
}
void halvor_ppc_interrupt(enum gpio_signal signal)
{
- /* TODO (b/153705222): Need tp implement three USB-C function */
+ /* TODO (b/153705222): Need to implement three USB-C function */
}
void halvor_bc12_interrupt(enum gpio_signal signal)
{
- /* TODO (b/153705222): Need tp implement three USB-C function */
+ /* TODO (b/153705222): Need to implement three USB-C function */
+}
+
+void board_reset_pd_mcu(void)
+{
+ /* TODO (b/153705222): Need to implement three USB-C function */
+}
+
+__override void board_cbi_init(void)
+{
+ /* TODO (b/153705222): Check FW_CONFIG for USB DB options */
}